VecSink

Trait VecSink 

pub trait VecSink: DataSink {
    // Required method
    fn write_owned_bytes(&mut self, buf: Vec<u8>) -> Result;
}
A sink stream of vector data.

Required Methods

fn write_owned_bytes(&mut self, buf: Vec<u8>) -> Result

Writes all bytes from a Vec.

Errors

May return Overflow if the sink would exceed some hard storage limit. In the case, the stream is filled completely, excluding the overflowing bytes.

Examples
use data_streams::VecSink;

let mut buf = Vec::new();
buf.write_owned_bytes(b"Hello!".into())?;
assert_eq!(buf, b"Hello!");
Implementation

By default, this delegates to write_bytes. Some implementations may be may better optimize for owned data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: DataSink> VecSink for T

Available on crate feature alloc and non-crate feature unstable_specialization only.